@@ -108,10 +108,36 @@ class NamedFilterQuery(FilterQuery):
             | {"name": f"{self.name} ({suffix})", "country": countries}
         )
 
+    def update_indicator_filter(
+        self, suffix: str, rsi_parameter_name: str
+    ) -> "NamedFilterQuery":
+        return NamedFilterQuery.model_validate(
+            self.model_dump()
+            | {"name": f"{self.name} ({suffix})", rsi_parameter_name: DATE_THRESHOLD}
+        )
+
     def variants(self) -> List["NamedFilterQuery"]:
         return [
             self.country_variant("Europe", list(get_args(Europe))),
             self.country_variant("Us", list(get_args(Us))),
+            self.country_variant("Europe", list(get_args(Europe)))
+            .update_indicator_filter("RSI 30", "rsi_bullish_crossover_30")
+            .update_indicator_filter("MACD", "macd_12_26_9_bullish_crossover"),
+            self.country_variant("Europe", list(get_args(Europe)))
+            .update_indicator_filter("RSI 40", "rsi_bullish_crossover_40")
+            .update_indicator_filter("MACD", "macd_12_26_9_bullish_crossover"),
+            self.country_variant("Europe", list(get_args(Europe)))
+            .update_indicator_filter("RSI Neutral", "rsi_neutral")
+            .update_indicator_filter("MACD", "macd_12_26_9_bullish_crossover"),
+            self.country_variant("Us", list(get_args(Us)))
+            .update_indicator_filter("RSI 30", "rsi_bullish_crossover_30")
+            .update_indicator_filter("MACD", "macd_12_26_9_bullish_crossover"),
+            self.country_variant("Us", list(get_args(Us)))
+            .update_indicator_filter("RSI 40", "rsi_bullish_crossover_40")
+            .update_indicator_filter("MACD", "macd_12_26_9_bullish_crossover"),
+            self.country_variant("Us", list(get_args(Us)))
+            .update_indicator_filter("RSI Neutral", "rsi_neutral")
+            .update_indicator_filter("MACD", "macd_12_26_9_bullish_crossover"),
         ]
 
 
@@ -126,17 +152,30 @@ SMALL_CAP = NamedFilterQuery(
 
 TOP_PERFORMERS = NamedFilterQuery(
     name="Top Performers",
+    volume_above_average=DATE_THRESHOLD,
     sma_50_above_sma_200=[
         datetime.date.today() - datetime.timedelta(days=5000),
-        datetime.date.today() - datetime.timedelta(days=10),
+        datetime.date.today(),
+    ],
+    weekly_growth=[1, 100],
+    monthly_growth=[8, 100],
+    order_by_desc="market_capitalization",
+).variants()
+
+TOP_PERFORMERS_YEARLY = NamedFilterQuery(
+    name="Top Performers Yearly",
+    sma_50_above_sma_200=[
+        datetime.date.today() - datetime.timedelta(days=5000),
+        datetime.date.today(),
     ],
     price_above_sma_50=[
         datetime.date.today() - datetime.timedelta(days=5000),
-        datetime.date.today() - datetime.timedelta(days=10),
+        datetime.date.today(),
     ],
     volume_above_average=DATE_THRESHOLD,
     weekly_growth=[1, 100],
     monthly_growth=[8, 100],
+    yearly_growth=[30, 100],
     order_by_desc="market_capitalization",
 ).variants()
 
@@ -151,24 +190,13 @@ NEXT_EARNINGS_DATE = NamedFilterQuery(
     order_by_desc="market_capitalization",
     next_earnings_date=[
         datetime.date.today(),
-        datetime.date.today() + timedelta(days=10),
+        datetime.date.today() + timedelta(days=20),
     ],
 ).variants()
-
-RSI_CROSSOVER_40 = NamedFilterQuery(
-    name="RSI cross-over 40",
-    rsi_bullish_crossover_40=DATE_THRESHOLD,
-    market_capitalization=[5e8, 1e13],
-    order_by_desc="market_capitalization",
-    country=["Germany", "United states", "France", "United kingdom", "Canada", "Japan"],
-).variants()
-
-RSI_CROSSOVER_30 = NamedFilterQuery(
-    name="RSI cross-over 30",
-    price_per_earning_ratio=[10, 500],
-    rsi_bullish_crossover_30=DATE_THRESHOLD,
-    market_capitalization=[5e8, 1e13],
+SOLD_POSITIONS = NamedFilterQuery(
+    name="Sold Positions",
     order_by_desc="market_capitalization",
+    symbol=["R3NK.DE", "VKTX", "RHM.DE", "IQV", "DAL"],
 ).variants()
 
 
@@ -176,10 +204,10 @@ def predefined_filters() -> list[NamedFilterQuery]:
     return [
         *SMALL_CAP,
         *TOP_PERFORMERS,
+        *TOP_PERFORMERS_YEARLY,
         *LARGE_CAPS,
         *NEXT_EARNINGS_DATE,
-        *RSI_CROSSOVER_40,
-        *RSI_CROSSOVER_30,
+        *SOLD_POSITIONS,
     ]
 
 
